# Contributing

## Issues
Please search [all the issues (open and closed)](https://github.com/mmargenot/lemurian/issues?q=is%3Aissue) before logging a new one.

When logging a bug, please make sure to include:
- A clear title and one-line description of the issue
- The version you're using
- An isolated way to reproduce the behavior
- The behavior you expect to see, and the actual behavior (with screenshots, if possible)

## Pull Requests
Outside contributors may suggest changes via Pull Requests and they will be reviewed ad hoc by the development team. Please include:
1. A detailed description of the changes, including the desired intent and thinking behind the changes.
2. Examples of the changes in behavior [if relevant].
3. Tests that validate functionality implemented with the changes.
